import React, { ComponentPropsWithoutRef } from 'react';
import { Orientation } from '../../../@types';
export interface IRadioGroupOption {
    description: string | React.ReactNode;
    disabled?: boolean;
    label: string | React.ReactNode;
    value: string | number;
    iconName?: string;
}
export interface IRadioGroupProps extends ComponentPropsWithoutRef<'input'> {
    /**
     * Defines disabled state
     */
    disabled?: boolean;
    /**
     * Defines label for SR-Only
     */
    label?: string;
    /**
     * Defines onChange event handler function
     */
    onChange: (value: any) => void;
    /**
     * Defines className for options wrapper element.
     */
    optionClassName?: string;
    /**
     * Defines options list
     */
    options: IRadioGroupOption[];
    /**
     * Defines Orientation. i.e "horizontal" or "vertical"
     */
    orientation?: keyof typeof Orientation;
    /**
     * Defines selected item value
     */
    value: any;
    /**
     * Defines whether to show Radio element in left.
     */
    isRadioAppearance?: boolean;
    /**
     * Defines the Radio appearance to show in right.
     */
    radioOnRight?: boolean;
}
export interface IRadioGroupOptionProps extends ComponentPropsWithoutRef<'option'> {
    index: number;
    option: IRadioGroupOption;
    isRadioAppearance?: boolean;
    radioOnRight?: boolean;
}
declare const RadioGroup: React.ForwardRefExoticComponent<IRadioGroupProps & React.RefAttributes<HTMLInputElement>>;
export declare const RadioGroupOption: ({ className, index, option, isRadioAppearance, radioOnRight, }: IRadioGroupOptionProps) => JSX.Element;
export default RadioGroup;
//# sourceMappingURL=RadioGroup.d.ts.map